WebKitSslAuthError class

An implementation of PlatformSslAuthError with the WebKit api.

Properties

certificate → X509Certificate?
The certificate associated with this error.
finalinherited
description String
A human-presentable description for a given error.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
host String
The host portion of the url associated with the error.
final
port int
The port portion of the url associated with the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() Future<void>
Instructs the WebView that encountered the SSL certificate error to terminate communication with the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
proceed() Future<void>
Instructs the WebView that encountered the SSL certificate error to ignore the error and continue communicating with the server.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited