cancel method

  1. @override
Future<void> cancel()

Instructs the WebView that encountered the SSL certificate error to terminate communication with the server.

The host application must call this method to prevent a resource from loading when an SSL certificate is invalid.

Implementation

@override
Future<void> cancel() async {
  await _onResponse(
    UrlSessionAuthChallengeDisposition.cancelAuthenticationChallenge,
    null,
  );
}