WebKitWebViewCookieManagerCreationParams class
Object specifying creation parameters for a WebKitWebViewCookieManager.
Constructors
- WebKitWebViewCookieManagerCreationParams()
- Constructs a WebKitWebViewCookieManagerCreationParams.
- WebKitWebViewCookieManagerCreationParams.fromPlatformWebViewCookieManagerCreationParams(PlatformWebViewCookieManagerCreationParams params)
-
Constructs a WebKitWebViewCookieManagerCreationParams using a
PlatformWebViewCookieManagerCreationParams.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited